@@ -10,7 +10,7 @@
 
 from __future__ import absolute_import, print_function
 
-from elasticsearch_dsl.query import Q
+from invenio_search.engine import dsl
 from invenio_search.api import RecordsSearch
 
 
@@ -21,6 +21,6 @@ class FrontpageRecordsSearch(RecordsSearch):
         """Default index and filter for frontpage search."""
 
         index = "rdmrecords-records"
-        default_filter = Q(
+        default_filter = dsl.Q(
             "query_string", query=("access.record:public AND versions.is_latest:true")
         )
