@@ -147,6 +147,10 @@ def create_blueprint(app):
 
         return metadata
 
+    @blueprint.app_template_global("record_count")
+    def record_count():
+        return FrontpageRecordsSearch().count()
+
     @blueprint.route("/")
     def tuw_index():
         """Custom landing page showing the latest 5 records."""
